=====================
Django DataDog Logger
=====================


.. image:: https://img.shields.io/pypi/v/django-datadog-logger.svg
        :target: https://pypi.python.org/pypi/django-datadog-logger

.. image:: https://img.shields.io/travis/namespace-ee/django-datadog-logger.svg
        :target: https://travis-ci.com/namespace-ee/django-datadog-logger

.. image:: https://readthedocs.org/projects/django-datadog-logger/badge/?version=latest
        :target: https://django-datadog-logger.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/namespace-ee/django-datadog-logger/shield.svg
     :target: https://pyup.io/repos/github/namespace-ee/django-datadog-logger/
     :alt: Updates



Django DataDog Logger integration package.


* Free software: MIT license
* Documentation: https://django-datadog-logger.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
